==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/pl.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "zapisywanie...",
    "saved!" : "zapisano!",
    "failed!" : "nie powiodło się!",
    "Saved" : "Zapisano",
    "There was a problem saving your changes. Click to resume editing." : "Pojawił się problem podczas zapisywania twoich zmian. Kliknij, aby powrócić do edycji.",
    "An error occurred!" : "Wystąpił błąd!",
    "Edit" : "Edytuj",
    "Mixed" : "Mieszane",
    "Preview" : "Podgląd",
    "New text file" : "Nowy plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt",
    "You can not open a folder" : "Nie możesz otworzyć folderu",
    "This file is too big to be opened. Please download the file instead." : "Plik jest zbyt duży by go otworzyć. Proszę pobrać plik",
    "Cannot read the file." : "Nie można odczytać pliku.",
    "Invalid file path supplied." : "Błędnie podana ścieżka do pliku.",
    "The file is locked." : "Plik jest zablokowany.",
    "An internal server error occurred." : "Wystąpił wewnętrzny błąd serwera.",
    "You can not write to a folder" : "Nie możesz wprowadzać zmian w folderze",
    "Cannot save file as it has been modified since opening" : "Nie mogę zapisać pliku, został zmodyfikowany podczas otwarcia.",
    "Insufficient permissions" : "Niewystarczające uprawnienia",
    "File path not supplied" : "Ścieżka pliku nie została podana",
    "File mtime not supplied" : "Plik mtime nie został podany",
    "Text editor" : "Edytor tekstu",
    "Text file" : "Plik tekstowy"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/pl.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "zapisywanie…",
    "saved!" : "zapisano!",
    "failed!" : "nie powiodło się!",
    "Saved" : "Zapisano",
    "There was a problem saving your changes. Click to resume editing." : "Pojawił się problem podczas zapisywania twoich zmian. Kliknij, aby powrócić do edycji.",
    "An error occurred!" : "Wystąpił błąd!",
    "Edit" : "Edytuj",
    "Mixed" : "Różne",
    "Preview" : "Podgląd",
    "New text file" : "Nowy plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt",
    "You can not open a folder" : "Nie możesz otworzyć folderu",
    "This file is too big to be opened. Please download the file instead." : "Plik jest zbyt duży by go otworzyć. Proszę pobrać plik",
    "Cannot read the file." : "Nie można odczytać pliku.",
    "Invalid file path supplied." : "Błędnie podana ścieżka do pliku.",
    "The file is locked." : "Plik jest zablokowany.",
    "An internal server error occurred." : "Wystąpił wewnętrzny błąd serwera.",
    "You can not write to a folder" : "Nie możesz wprowadzać zmian w folderze",
    "Cannot save file as it has been modified since opening" : "Nie mogę zapisać pliku, został zmodyfikowany podczas otwarcia.",
    "Could not write to file." : "Nie można zapisać pliku.",
    "Insufficient permissions" : "Niewystarczające uprawnienia",
    "File path not supplied" : "Ścieżka pliku nie została podana",
    "File mtime not supplied" : "Plik mtime nie został podany",
    "Share not found" : "Udział nie znaleziony",
    "You are not authorized to open this share" : "Nie masz uprawnień do otwarcia tego udziału",
    "Text editor" : "Edytor tekstu"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
